==> pgmarket-1.5.0.tar.gz: pgmarket-1.5.0/firstpage.php <==
<?
/* index.php (c) 2000 Ying Zhang (ying@zippydesign.com)
 *
 * TERMS OF USAGE:
 * This file was written and developed by Ying Zhang (ying@zippydesign.com)
 * for educational and demonstration purposes only.  You are hereby granted the 
 * rights to use, modify, and redistribute this file as you like.  The only
 * requirement is that you must retain this notice, without modifications, at
 * the top of your source code.  No warranties or guarantees are expressed or
 * implied. DO NOT use this code in a production environment without
 * understanding the limitations and weaknesses pretaining to or caused by the
 * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
 */

/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */

/******************************************************************************
 * MAIN
 *****************************************************************************/

include("application.inc.php");

$DOC_TITLE = "PgMarket_Home_Page";

include("$CFG->dirroot"."/header.php");

load_special_products(&$qid);
$t = new Template($CFG->templatedir.$SESSION["lang"]."/", "keep");
require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
require($CFG->localedir . $SESSION["lang"] . "/global-shopping.inc.php");
$t->set_file(array(
		"page"			=> $CFG->templatedir.$SESSION["lang"]."/index.ihtml",
		"special_products"	=> $CFG->templatedir."special_products.ihtml"
));
$t->set_var(array(
		"cfg_myname"	=> $CFG->myname,
		"wwwroot"	=> $CFG->wwwroot,
));
$t->set_block("page", "there_are_special_products", "there_are_special_products_blck");
if (!(($numr = db_num_rows($qid)) > 0))
//if(1)
	$t->set_var(array("there_are_special_products_blck" => ""));
else {
	$t->set_block("special_products", "special_products_product", "special_products_products");
	$t->set_var(array("special_products_products" => ""));
		$t->set_block("special_products_product", "brand_used", "brand_used_blck");
		$t->set_block("special_products_product", "iva_used", "iva_used_blck");
		$t->set_block("special_products_product", "discount_block", "discount_block_blck");
			$t->set_block("discount_block", "discqty_block", "discqty_block_blck");
		$t->set_block("special_products_product", "weight_used", "weight_used_blck");
	for ($i=0; $i<$numr; $i++) {
		$t->set_var(array("brand_used_blck" => ""));
		$t->set_var(array("iva_used_blck" => ""));
		$t->set_var(array("discount_block_blck" => ""));
			$t->set_var(array("discqty_block_blck" => ""));
		$t->set_var(array("weight_used_blck" => ""));
		$r = db_fetch_object($qid, $i);
		$t->set_var(array(
				"r_id"		=> $r->id,
				"r_name"	=> $r->name,
				"r_description"	=> ovwbr($r->description),
				"r_price"	=> $r->price,
				"r_fprice"	=> formatted_price($r->price)
		));
		if ($SESSION["brand_used"] && $r->bname != "") {
			$t->set_var("r_bname", ov($r->bname));
			$t->parse("brand_used_blck", "brand_used");
		}
		if ($SESSION["iva_used"]) {
			$t->set_var("r_iva", $r->iva);
			$t->parse("iva_used_blck", "iva_used");
		}
		if ($r->discount > 0) {
			$t->set_var("r_discount", $r->discount);
			if ($r->discqty > 1) {
				$t->set_var("r_discqty", $r->discqty);
				$t->parse("discqty_block_blck", "discqty_block", true);
			}
			$t->parse("discount_block_blck", "discount_block", true);
		}
		if ($SESSION["weight_used"]) {
			$t->set_var(array(
					"r_weight"	=> $r->weight,
					"r_fweight"	=> formatted_weight($r->weight)
			));
			$t->parse("weight_used_blck", "weight_used");
		}
		$t->parse("special_products_products", "special_products_product", true);
	}
	$t->parse("there_are_special_products_blck", "there_are_special_products", true);
}
$t->pparse("out", array("special_products", "page"));
//$t->parse("out", "special_products");
//$t->parse("out", "page");
//$t->p("out");
//include($CFG->templatedir.$SESSION["lang"]."/index.ihtml");

include("$CFG->dirroot"."/footer.php");

/******************************************************************************
 * FUNCTIONS
 *****************************************************************************/

function load_special_products(&$qid) {
/* loads the list of special products */
	global $CFG;
	global $SESSION;
	global $weightunity;
	include ($CFG->globalerror);

	$qid = db_query("
			SELECT p.*, b.name AS bname, i.iva
			FROM products p, brands b, iva i
			WHERE p.brand_id = b.id AND p.iva_id = i.id AND special_flag = 1
			ORDER BY special_level ASC
			");
}

?>

==> pgmarket-1.5.1.tar.gz: pgmarket-1.5.1/firstpage.php <==
<?
/* index.php (c) 2000 Ying Zhang (ying@zippydesign.com)
 *
 * TERMS OF USAGE:
 * This file was written and developed by Ying Zhang (ying@zippydesign.com)
 * for educational and demonstration purposes only.  You are hereby granted the 
 * rights to use, modify, and redistribute this file as you like.  The only
 * requirement is that you must retain this notice, without modifications, at
 * the top of your source code.  No warranties or guarantees are expressed or
 * implied. DO NOT use this code in a production environment without
 * understanding the limitations and weaknesses pretaining to or caused by the
 * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
 */

/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */

/******************************************************************************
 * MAIN
 *****************************************************************************/

include("application.inc.php");

$DOC_TITLE = "PgMarket_Home_Page";

include("$CFG->dirroot"."/header.php");

$qid = new DB_Sql;
$qid->Query("
	SELECT p.*, b.name AS bname, i.iva
	FROM products p, brands b, iva i
	WHERE p.brand_id = b.id AND p.iva_id = i.id AND special_flag = 1
	ORDER BY special_level ASC
");
$t = new Template($CFG->templatedir.$SESSION["lang"]."/", "keep");
require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
require($CFG->localedir . $SESSION["lang"] . "/global-shopping.inc.php");
$t->set_file(array(
		"page"			=> $CFG->templatedir.$SESSION["lang"]."/index.ihtml",
		"special_products"	=> $CFG->templatedir."special_products.ihtml"
));
$t->set_var(array(
		"cfg_myname"	=> $CFG->myname,
		"wwwroot"	=> $CFG->wwwroot,
));
$t->set_block("page", "there_are_special_products", "there_are_special_products_blck");
//if (!(($numr = db_num_rows($qid)) > 0))
if (!($qid->num_rows() > 0))
//if(1)
	$t->set_var(array("there_are_special_products_blck" => ""));
else {
	$t->set_block("special_products", "special_products_product", "special_products_products");
	$t->set_var(array("special_products_products" => ""));
		$t->set_block("special_products_product", "brand_used", "brand_used_blck");
		$t->set_block("special_products_product", "iva_used", "iva_used_blck");
		$t->set_block("special_products_product", "discount_block", "discount_block_blck");
			$t->set_block("discount_block", "discqty_block", "discqty_block_blck");
		$t->set_block("special_products_product", "weight_used", "weight_used_blck");
//	for ($i=0; $i<$numr; $i++) {
	while ($qid->next_record()) {
		$t->set_var(array("brand_used_blck" => ""));
		$t->set_var(array("iva_used_blck" => ""));
		$t->set_var(array("discount_block_blck" => ""));
			$t->set_var(array("discqty_block_blck" => ""));
		$t->set_var(array("weight_used_blck" => ""));
//		$r = db_fetch_object($qid, $i);
		$t->set_var(array(
				"r_id"		=> $qid->f("id"),
				"r_name"	=> $qid->f("name"),
				"r_description"	=> ovwbr($qid->f("description")),
				"r_price"	=> $qid->f("price"),
				"r_fprice"	=> formatted_price($qid->f("price"))
		));
		if ($SESSION["brand_used"] && $qid->f("bname") != "") {
			$t->set_var("r_bname", ov($qid->f("bname")));
			$t->parse("brand_used_blck", "brand_used");
		}
		if ($SESSION["iva_used"]) {
			$t->set_var("r_iva", $qid->f("iva"));
			$t->parse("iva_used_blck", "iva_used");
		}
		if ($qid->f("discount") > 0) {
			$t->set_var("r_discount", $qid->f("discount"));
			if ($qid->f("discqty") > 1) {
				$t->set_var("r_discqty", $qid->f("discqty"));
				$t->parse("discqty_block_blck", "discqty_block", true);
			}
			$t->parse("discount_block_blck", "discount_block", true);
		}
		if ($SESSION["weight_used"]) {
			$t->set_var(array(
					"r_weight"	=> $qid->f("weight"),
					"r_fweight"	=> formatted_weight($qid->f("weight"))
			));
			$t->parse("weight_used_blck", "weight_used");
		}
		$t->parse("special_products_products", "special_products_product", true);
	}
	$t->parse("there_are_special_products_blck", "there_are_special_products", true);
}
$t->pparse("out", array("special_products", "page"));
//$t->parse("out", "special_products");
//$t->parse("out", "page");
//$t->p("out");
//include($CFG->templatedir.$SESSION["lang"]."/index.ihtml");

include("$CFG->dirroot"."/footer.php");

?>
